FAQ
=================


    1. *Does tsfresh supports different time series lengths?*
       Yes, it supports different time series lenghts. However, some feature calculators could demand a minimal length
       of the time series. If a shorter time series is passed to the calculator, normally a NaN is returned.

